@@ -385,6 +385,25 @@ class TestContainer(base.BaseTestCase):
         self.assertTrue(self.dw.changed)
         self.assertFalse(self.dw.dc.create_host_config.call_args[1]['tmpfs'])
 
+    def test_create_container_create_volumes(self):
+        self.fake_data['params']['volumes'] = [
+            "kolla_logs:/var/log/kolla/",
+            "fluentd_data:/var/lib/fluentd/data/",
+            "/var/log/journal:/var/log/journal:ro",
+            "/etc/kolla/fluentd/:/var/lib/kolla/config_files/:ro"
+        ]
+        self.dw = get_DockerWorker(self.fake_data['params'])
+
+        self.dw.create_volume = mock.MagicMock()
+        self.dw.create_container()
+        expected_calls = [
+            mock.call(name="kolla_logs"),
+            mock.call(name="fluentd_data")
+        ]
+
+        self.dw.create_volume.assert_has_calls(expected_calls, any_order=True)
+        self.assertEqual(self.dw.create_volume.call_count, 2)
+
     def test_start_container_without_pull(self):
         params = {
             'auth_username': 'fake_user',
@@ -697,62 +716,6 @@ class TestContainer(base.BaseTestCase):
             force=True
         )
 
-    def test_get_container_env(self):
-        fake_env = dict(KOLLA_BASE_DISTRO='ubuntu')
-        self.dw = get_DockerWorker({'name': 'my_container',
-                                    'action': 'get_container_env'})
-        self.dw.dc.containers.return_value = self.fake_data['containers']
-        self.fake_data['container_inspect'].update(
-            self.fake_data['containers'][0])
-        self.dw.dc.inspect_container.return_value = (
-            self.fake_data['container_inspect'])
-        self.dw.get_container_env()
-
-        self.assertFalse(self.dw.changed)
-        self.dw.dc.containers.assert_called_once_with(all=True)
-        self.dw.dc.inspect_container.assert_called_once_with('my_container')
-        self.dw.module.exit_json.assert_called_once_with(**fake_env)
-
-    def test_get_container_env_negative(self):
-        self.dw = get_DockerWorker({'name': 'fake_container',
-                                    'action': 'get_container_env'})
-        self.dw.dc.containers.return_value = self.fake_data['containers']
-        self.dw.get_container_env()
-
-        self.assertFalse(self.dw.changed)
-        self.dw.module.fail_json.assert_called_once_with(
-            msg="No such container: fake_container")
-
-    def test_get_container_state(self):
-        State = {'Dead': False,
-                 'ExitCode': 0,
-                 'Pid': 12475,
-                 'StartedAt': '2016-06-07T11:22:37.66876269Z',
-                 'Status': 'running'}
-        self.fake_data['container_inspect'].update({'State': State})
-        self.dw = get_DockerWorker({'name': 'my_container',
-                                    'action': 'get_container_state'})
-        self.dw.dc.containers.return_value = self.fake_data['containers']
-        self.dw.dc.inspect_container.return_value = (
-            self.fake_data['container_inspect'])
-        self.dw.get_container_state()
-
-        self.assertFalse(self.dw.changed)
-        self.dw.dc.containers.assert_called_once_with(all=True)
-        self.dw.dc.inspect_container.assert_called_once_with('my_container')
-        self.dw.module.exit_json.assert_called_once_with(**State)
-
-    def test_get_container_state_negative(self):
-        self.dw = get_DockerWorker({'name': 'fake_container',
-                                    'action': 'get_container_state'})
-        self.dw.dc.containers.return_value = self.fake_data['containers']
-        self.dw.get_container_state()
-
-        self.assertFalse(self.dw.changed)
-        self.dw.dc.containers.assert_called_once_with(all=True)
-        self.dw.module.fail_json.assert_called_once_with(
-            msg="No such container: fake_container")
-
     def test_recreate_or_restart_container_not_container(self):
         self.dw = get_DockerWorker({
             'environment': dict(KOLLA_CONFIG_STRATEGY='COPY_ALWAYS')})
@@ -1152,7 +1115,8 @@ class TestVolume(base.BaseTestCase):
         self.assertTrue(self.dw.changed)
         self.dw.dc.create_volume.assert_called_once_with(
             name='rabbitmq',
-            driver='local')
+            driver='local',
+            labels={'kolla_managed': 'true'})
 
     def test_create_volume_exists(self):
         self.dw = get_DockerWorker({'name': 'nova_compute',
